
Insecure datastorage
-------

**Description:**

Whenever sensitive data is stored clear-text this data is compromised as soon as it 
falls into the hands of an attacker.



**Solution:**

Sensitive data in all forms should always be stored by an encrypted manner.
We recommend to follow the "Secure Cryptographic datastorage" cheatsheet found on OWASP.

https://www.owasp.org/index.php/Cryptographic_Storage_Cheat_Sheet


	